//sms.java
//uses SMSLib from http://www.suitable.com/tools/smslib.html
//Based on code by Daniel Shiffman for sms

// Created by derDoc (derdoc@gmx.de)

package SMSlib;


public class sms {


    // Native functions
    private static native float[] 	readSMS();
    private static native int 		startup();
    private static native void	 	shutdown();
    private static native boolean 	calibrate();
	private static native String	caliDesc();


	private static final String Msgs[] = {  "Success", 
											"Connection to sensor failed", 
											"Failed opening sensor", 
											"Failed to find the motion service",
											"Failed to get list of services",
											"Failed getting dictionary matching desrired service",
											"Unsupported Computer Model"
										};
										

	private static boolean isRunning = false;
	

	//determine if its running
	public static boolean isRunning(){
		return isRunning;
	}

	//load a previously stored calibration record, and use it
	public static boolean load_calibration(){
		return calibrate();
	}

    // Return three values as array
    public static float[] getSMSArray() {
        if (!isRunning) return null;
        return readSMS();
    }
    
    // Return just the X
    public static float getSMSX() {
        if (!isRunning) return Float.NaN;
        return readSMS()[0];
    }

    // Return just the Y
    public static float getSMSY() {
        if (!isRunning) return Float.NaN;
        return readSMS()[1];
    }

    // Return just the Z
    public static float getSMSZ() {
        if (!isRunning) return Float.NaN;
        return readSMS()[2];
    }
    
    //called on destroying the sketch
    public static void dispose() {
    	shutdown();
    	isRunning = false;
    }

	//test the class
	public static void main(String[] args){
	
		if (!isRunning){
			System.out.println("Error starting SMSlib!");
			return;
		}
		System.out.println("Attached to SMSlib, getting description...");
		System.out.println(caliDesc());
		
		System.out.println("trying to calibrate...");
		boolean cali = calibrate();
		System.out.println("Calibration: " + (cali ? "success":"falied"));
		
		float[] vals;
		System.out.println("Reading sensor data...");
		
		for (int i = 0; i < 2000; i ++){
			vals = getSMSArray();
			System.out.println("Values: x=" + vals[0] + ", y=" + vals[1] + ", z=" + vals[2]);
			
			try{
				Thread.sleep(500);
			}catch(Exception e){ }
		}
	}

    
    // Load the JNI Interface, called when the class is loaded by the classloader
    static {    	
        System.loadLibrary("SMSLib");
        
        int res = startup();
        System.out.println("Attaching to sensor... " + Msgs[(res * (-1))] );
        
        if ( res == 0){
        	isRunning=true;
			calibrate();
		}
    }

}

